# Generated by roxygen2: do not edit by hand

S3method(as.data.frame,MeasureEnv)
S3method(print,MeasureEnv)
S3method(print,confusion_matrix)
export(acc)
export(ae)
export(ape)
export(auc)
export(bacc)
export(bbrier)
export(bias)
export(ce)
export(confusion_matrix)
export(dor)
export(fbeta)
export(fdr)
export(fn)
export(fnr)
export(fomr)
export(fp)
export(fpr)
export(gmean)
export(gpr)
export(jaccard)
export(ktau)
export(linex)
export(logloss)
export(mae)
export(mape)
export(mauc_au1p)
export(mauc_au1u)
export(mauc_aunp)
export(mauc_aunu)
export(mauc_mu)
export(maxae)
export(maxse)
export(mbrier)
export(mcc)
export(measures)
export(medae)
export(medse)
export(mse)
export(msle)
export(npv)
export(obs_logloss)
export(one_zero)
export(pbias)
export(phi)
export(pinball)
export(ppv)
export(prauc)
export(precision)
export(rae)
export(recall)
export(rmse)
export(rmsle)
export(rrse)
export(rse)
export(rsq)
export(sae)
export(se)
export(se_binary)
export(sensitivity)
export(sle)
export(smape)
export(specificity)
export(srho)
export(sse)
export(tn)
export(tnr)
export(tp)
export(tpr)
export(zero_one)
import(checkmate)
importFrom(stats,ave)
importFrom(stats,contr.treatment)
importFrom(stats,cor)
importFrom(stats,median)
importFrom(stats,relevel)
importFrom(stats,var)
importFrom(stats,xtabs)
importFrom(utils,bibentry)
importFrom(utils,combn)
importFrom(utils,head)
